@@ -2,7 +2,7 @@ import os
 import streamlit as st
 import streamlit.components.v1 as components
 
-_RELEASE = False
+_RELEASE = True
 
 if _RELEASE:
 
